#ifndef NT2_INCLUDE_FUNCTIONS_HYPOT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_HYPOT_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/hypot.hpp>

#endif
